@@ -2,11 +2,11 @@
 #include "mainwindow.h"
 #include "LocationModule.h"
 #include <QTimer>
-SpeedoMeter *pW;
+Speedo *pW;
 int main(int argc, char *argv[])
 {
     QApplication a(argc, argv);
-    SpeedoMeter w;
+    Speedo w;
 
     pW = &w;
     w.show();
